==> jboss-metadata-common-7.0.8.Final-redhat-1-test-sources.jar: org/jboss/test/metadata/common/SetHelper.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2007, Red Hat Middleware LLC, and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.metadata.common;

import java.util.HashSet;
import java.util.Set;

/**
 * A utility class to handle sets.
 *
 * @author <a href="mailto:carlo.dewolf@jboss.com">Carlo de Wolf</a>
 * @version $Revision: 67290 $
 */
public class SetHelper
{
   /**
    * Create a generic set from a variable amount of objects.
    * 
    * @param <T>    the type of element in the set
    * @param obj    the objects
    * @return       the created set
    */
   public static <T> Set<T> createSet(T ... obj)
   {
      Set<T> set = new HashSet<T>();
      for(T o : obj)
      {
         set.add(o);
      }
      return set;
   }
}

==> jboss-metadata-common-10.0.2.Final-redhat-1-test-sources.jar: org/jboss/test/metadata/common/SetHelper.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.metadata.common;

import java.util.HashSet;
import java.util.Set;

/**
 * A utility class to handle sets.
 *
 * @author <a href="mailto:carlo.dewolf@jboss.com">Carlo de Wolf</a>
 * @version $Revision: 67290 $
 */
public class SetHelper {
    /**
     * Create a generic set from a variable amount of objects.
     *
     * @param <T> the type of element in the set
     * @param obj the objects
     * @return the created set
     */
    public static <T> Set<T> createSet(T... obj) {
        Set<T> set = new HashSet<T>();
        for (T o : obj) {
            set.add(o);
        }
        return set;
    }
}
